@@ -62,11 +62,11 @@ test_that("get_ts gdf multi works", {
   flow <- get_ts(id = c(54022, 54090, 54091), type = "gdf")
   expect_true(class(flow) == "list")
   expect_true(class(flow[[1]]) == "zoo")
-  expect_equal(as.numeric(flow[[1]][1]), 0.637)
+  expect_equal(as.numeric(flow[[1]][zoo::index(flow[[1]]) == "1953-10-01"]), 0.637)
   expect_true(length(flow[[1]]) >= 16855)
-  expect_equal(as.numeric(flow[[2]][1]), 0.031)
+  expect_equal(as.numeric(flow[[2]][zoo::index(flow[[2]]) == "1973-10-01"]), 0.031)
   expect_true(length(flow[[2]]) >= 13159)
-  expect_equal(as.numeric(flow[[3]][1]), 1.262)
+  expect_equal(as.numeric(flow[[3]][zoo::index(flow[[3]]) == "1976-01-01"]), 1.262)
   expect_true(length(flow[[3]]) >= 12416)
 
 })
